@@ -6,9 +6,10 @@ from typing import List, Optional, Literal
 from datetime import datetime
 
 from letschatty.models.utils.types.message_types import MessageType
-from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import ChainOfThoughtInChatRequest, IncomingMessageAIDecision, IncomingMessageDecisionAction
+from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import ChainOfThoughtInChatRequest, IncomingMessageAIDecision, IncomingMessageDecisionAction, SmartFollowUpDecision, SmartFollowUpDecisionAction
 from ...models.company.assets.automation import Automation
 from ...models.company.form_field import CollectedData
+from ...models.chat.chat import Area
 
 class ExpectedOutputQualityTest(BaseModel):
     accuracy: float = Field(description="The accuracy of the comparison analysis")
@@ -161,3 +162,31 @@ class ExpectedOutputIncomingMessage(BaseModel):
         return incoming_decision
 
 
+class ExpectedOutputSmartFollowUp(BaseModel):
+    action: SmartFollowUpDecisionAction
+    messages: List[str] = Field(description="Array of message strings to send to the customer. Required for send/suggest actions, optional for escalate action, empty array for skip/remove/postpone actions.")
+    chain_of_thought: ChainOfThoughtInChatRequest = Field(description="REQUIRED: Your reasoning process and response decision explanation")
+    next_call_time: Optional[datetime] = Field(default=None, description="The next call time for the smart follow up (required for postpone_delta_time action)")
+    reason: Optional[str] = Field(default=None, description="Reason for the decision (especially for postpone/postponed actions)")
+    area: Optional[Area] = Field(default=None, description="The area to move the chat after the decision")
+
+    def to_smart_follow_up_decision_output(self) -> SmartFollowUpDecision:
+        messages_drafts = [
+            MessageDraft(
+                type=MessageType.TEXT,
+                content=ChattyContentText(body=message),
+                is_incoming_message=False
+            )
+            for message in self.messages
+        ]
+        smart_follow_up_decision = SmartFollowUpDecision(
+            action=self.action,
+            next_call_time=self.next_call_time,
+            messages=messages_drafts,
+            chain_of_thought=self.chain_of_thought,
+            reason=self.reason,
+            area=self.area
+        )
+        return smart_follow_up_decision
+
+
