@@ -6,7 +6,7 @@ from typing import Dict, Any, List, Optional, TYPE_CHECKING
 from letschatty.models.base_models.ai_agent_component import AiAgentComponentType
 from letschatty.models.utils.types.identifier import StrObjectId
 from .lambda_invokation_types import InvokationType, LambdaAiEvent
-from .expected_output import ExpectedOutputIncomingMessage, ExpectedOutputSmartTag, ExpectedOutputQualityTest, IncomingMessageAIDecision
+from .expected_output import ExpectedOutputIncomingMessage, ExpectedOutputSmartFollowUp, ExpectedOutputSmartTag, ExpectedOutputQualityTest, IncomingMessageAIDecision
 from ...models.company.assets.ai_agents_v2.ai_agents_decision_output import IncomingMessageDecisionAction, SmartFollowUpDecision
 
 class SmartTaggingCallbackMetadata(BaseModel):
@@ -25,6 +25,7 @@ class InteractionCallbackMetadata(BaseModel):
     company_id: StrObjectId
     interaction_index: int
     trigger: ChainOfThoughtInChatTrigger
+    chain_of_thought_id: StrObjectId
 
 class QualityTestCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SINGLE_QUALITY_TEST_CALLBACK
@@ -42,6 +43,50 @@ class QualityTestInteractionCallbackEvent(LambdaAiEvent):
             data["data"]["chain_of_thought"]["chatty_ai_agent_id"] = data["callback_metadata"]["ai_agent_id"]
         return data
 
+    @model_validator(mode="before")
+    @classmethod
+    def set_chain_of_thought_id(cls, values: Dict[str, Any]):
+        """
+        Get the chain_of_thought_id from callback_metadata and set it in data.chain_of_thought.id
+
+        Handles both cases:
+        - data is a JSON string (needs parsing)
+        - data is already a dict
+        """
+        import json
+
+        data = values.get("data")
+        callback_metadata = values.get("callback_metadata")
+
+        if not data or not callback_metadata:
+            return values
+
+        # Get chain_of_thought_id from callback_metadata (could be dict or object)
+        if isinstance(callback_metadata, dict):
+            chain_of_thought_id = callback_metadata.get("chain_of_thought_id")
+        else:
+            chain_of_thought_id = getattr(callback_metadata, "chain_of_thought_id", None)
+
+        if not chain_of_thought_id:
+            return values
+
+        # Parse data if it's a JSON string
+        if isinstance(data, str):
+            try:
+                data = json.loads(data)
+                values["data"] = data
+            except (json.JSONDecodeError, TypeError):
+                return values
+
+        # If data is a dict, set the id in chain_of_thought
+        if isinstance(data, dict):
+            chain_of_thought = data.get("chain_of_thought")
+            if isinstance(chain_of_thought, dict):
+                chain_of_thought["id"] = chain_of_thought_id
+
+        return values
+
+
 class SmartTaggingCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.SMART_TAGGING_CALLBACK
     data: ExpectedOutputSmartTag
@@ -110,42 +155,60 @@ class DoubleCheckerCallbackMetadata(BaseModel):
     company_id: StrObjectId
     ai_agent_id: StrObjectId
     incoming_messages_ids: List[str]
-    # Trigger info
     trigger: ChainOfThoughtInChatTrigger
-    # Trigger info is in: incoming_messages_ids for user_message,
-    # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
-    triggered_by_user_id: Optional[StrObjectId] = None
+    chain_of_thought_id: StrObjectId
+
 
 class DoubleCheckerForIncomingMessagesAnswerEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER
     data: DoubleCheckerForIncomingMessagesAnswerData
 
-class DoubleCheckerForIncomingMessagesAnswerCallbackMetadata(BaseModel):
-    chat_id: StrObjectId
-    company_id: StrObjectId
-    ai_agent_id: StrObjectId
-    chain_of_thought_id: StrObjectId
-
 class DoubleCheckerForIncomingMessagesAnswerCallbackEvent(LambdaAiEvent):
     type: InvokationType = InvokationType.DOUBLE_CHECKER_FOR_INCOMING_MESSAGES_ANSWER_CALLBACK
     data: ExpectedOutputIncomingMessage
-    callback_metadata: DoubleCheckerForIncomingMessagesAnswerCallbackMetadata
+    callback_metadata: DoubleCheckerCallbackMetadata
 
     @model_validator(mode="before")
     @classmethod
     def set_chain_of_thought_id(cls, values: Dict[str, Any]):
         """
-        Get the chain_of_thought_id from callback_metadata and set it in data.chain_of_thought
+        Get the chain_of_thought_id from callback_metadata and set it in data.chain_of_thought.id
+
+        Handles both cases:
+        - data is a JSON string (needs parsing)
+        - data is already a dict
         """
+        import json
+
         data = values.get("data")
         callback_metadata = values.get("callback_metadata")
-        if data and callback_metadata:
-            # Set chain_of_thought_id in data.chain_of_thought if possible
+
+        if not data or not callback_metadata:
+            return values
+
+        # Get chain_of_thought_id from callback_metadata (could be dict or object)
+        if isinstance(callback_metadata, dict):
+            chain_of_thought_id = callback_metadata.get("chain_of_thought_id")
+        else:
             chain_of_thought_id = getattr(callback_metadata, "chain_of_thought_id", None)
-            chain_of_thought = getattr(data, "chain_of_thought", None)
-            if chain_of_thought_id and chain_of_thought:
-                # Set the id if possible; fallback to update dict if needed
+
+        if not chain_of_thought_id:
+            return values
+
+        # Parse data if it's a JSON string
+        if isinstance(data, str):
+            try:
+                data = json.loads(data)
+                values["data"] = data
+            except (json.JSONDecodeError, TypeError):
+                return values
+
+        # If data is a dict, set the id in chain_of_thought
+        if isinstance(data, dict):
+            chain_of_thought = data.get("chain_of_thought")
+            if isinstance(chain_of_thought, dict):
                 chain_of_thought["id"] = chain_of_thought_id
+
         return values
 
 
@@ -157,7 +220,7 @@ class SmartFollowUpDecisionOutputData(BaseModel):
     chat_id: StrObjectId
     company_id: StrObjectId
     ai_agent_id: StrObjectId
-    smart_follow_up_decision: 'SmartFollowUpDecision'
+    smart_follow_up_output: ExpectedOutputSmartFollowUp
     smart_follow_up_id: Optional[StrObjectId] = None
 
 class SmartFollowUpDecisionOutputEvent(LambdaAiEvent):
