@@ -1,3 +1,4 @@
+from letschatty.models.chat.chat import Area
 from pydantic import BaseModel, Field, model_validator
 from enum import StrEnum
 from datetime import datetime
@@ -16,6 +17,8 @@ class SmartFollowUpDecisionAction(StrEnum):
     SUGGEST = "suggest"
     REMOVE = "remove"
     ESCALATE = "escalate"
+    POSTPONE_TILL_UPDATE = "postpone_till_update"
+    POSTPONE_DELTA_TIME = "postpone_delta_time"
 
 class SmartFollowUpDecision(BaseModel):
     """Decision for the smart follow up"""
@@ -23,6 +26,8 @@ class SmartFollowUpDecision(BaseModel):
     next_call_time: Optional[datetime] = Field(description="The next call time for the smart follow up", default=None)
     messages : Optional[List[MessageDraft]] = Field(description="The messages to send to the chat", default=[])
     chain_of_thought: ChainOfThoughtInChatRequest = Field(description="The chain of thought for the smart follow up")
+    reason: Optional[str] = Field(description="Reason for the decision (especially for postpone/postponed actions)", default=None)
+    area: Optional[Area] = Field(description="The area to move the chat after the decision", default=None)
 
     @property
     def next_call_time_value(self) -> datetime:
@@ -46,6 +51,11 @@ class SmartFollowUpDecision(BaseModel):
         elif self.action == SmartFollowUpDecisionAction.ESCALATE:
             #messages here are optional
             pass
+        elif self.action in [SmartFollowUpDecisionAction.POSTPONE_TILL_UPDATE,
+                            SmartFollowUpDecisionAction.POSTPONE_DELTA_TIME]:
+            # Postpone actions don't require messages
+            if self.messages is not None and len(self.messages) > 0:
+                raise ValueError("Messages are not allowed when action is postpone")
         else:
             raise ValueError(f"Invalid action: {self.action}")
 
