@@ -1,4 +1,4 @@
-from pydantic import ConfigDict, Field, BaseModel
+from pydantic import ConfigDict, Field, BaseModel, model_validator
 from typing import Optional, List
 from ....base_models import CompanyAssetModel
 from ....utils.types.identifier import StrObjectId
@@ -8,6 +8,7 @@ from ....base_models.chatty_asset_model import ChattyAssetPreview
 from typing import ClassVar, Type, Any, Dict
 from datetime import datetime
 from zoneinfo import ZoneInfo
+from bson import ObjectId
 
 class ChainOfThoughtInChatTrigger(StrEnum):
     """Trigger for the chain of thought in chat"""
@@ -29,7 +30,7 @@ class ChainOfThoughtInChatStatus(StrEnum):
 
 class ChainOfThoughtInChatRequest(BaseModel):
     """Request for the chain of thought in chat"""
-    id: Optional[StrObjectId] = Field(default=None, description="The id of the chain of thought")
+    id: StrObjectId = Field(description="The id of the chain of thought")
     trigger: ChainOfThoughtInChatTrigger
     # trigger_id removed - trigger info is in: incoming_message_ids for user_message,
     # triggered_by_user_id for manual_trigger, smart_follow_up_id for follow_up
@@ -43,6 +44,22 @@ class ChainOfThoughtInChatRequest(BaseModel):
         arbitrary_types_allowed=True
                 )
 
+    @model_validator(mode='before')
+    @classmethod
+    def auto_generate_id_for_tagger(cls, data: Any) -> Any:
+        """
+        Auto-generate id for tagger executions (AUTOMATIC_TAGGING trigger).
+        This ensures tagger callbacks always have an id even if not provided.
+        Other triggers must provide the id explicitly (since it was previously generated when the get chat with prompt was called)
+        """
+        if isinstance(data, dict):
+            trigger = data.get('trigger')
+            # Only auto-generate for AUTOMATIC_TAGGING trigger if id is missing
+            if (trigger == ChainOfThoughtInChatTrigger.AUTOMATIC_TAGGING or
+                trigger == ChainOfThoughtInChatTrigger.AUTOMATIC_TAGGING.value) and not data.get('id'):
+                data['id'] = str(ObjectId())
+        return data
+
     @classmethod
     def example(cls) -> dict:
         return {
@@ -58,6 +75,8 @@ class ChainOfThoughtInChatRequest(BaseModel):
             raise ValueError("Chain of thought is not set")
         return self.chain_of_thought
 
+
+
 class ChainOfThoughtInChatPreview(ChattyAssetPreview):
     """Preview of the chain of thought in chat"""
     chat_id : StrObjectId
