@@ -2,6 +2,7 @@ from pydantic import Field, ConfigDict, field_validator, SecretStr, model_valida
 from typing import Optional, List, Dict
 
 from letschatty.models.chat.client import QualityScore
+from letschatty.models.company.company_messaging_settgins import MessagingSettings
 from ..base_models import ChattyAssetModel
 from letschatty.models.channels.channel import WhatsAppClientInfo
 from letschatty.models.utils.types import StrObjectId
@@ -32,11 +33,14 @@ class EmpresaModel(ChattyAssetModel):
     hammer_credentials: Optional[Dict[str,str]] = Field(default = None, description="Only usef for hammer propiedades real state agencies")
     continuous_conversation_template_name: Optional[str] = Field(default = None, description="The name of the continuous conversation template")
     default_follow_up_strategy_id: Optional[StrObjectId] = Field(default = None, description="The id of the default follow up strategy")
-    good_quality_score_definition: Optional[str] = Field(default = None, description="When a chat should be qualified as good")
+    messaging_settings: MessagingSettings = Field(default = MessagingSettings(), description="The messaging settings for the company")
+
 
     model_config = ConfigDict(
-        populate_by_name=True
-    )
+        validate_by_name=True,
+        validate_by_alias=True
+                )
+
 
     @field_validator("display_phone_number", mode="before")
     def validate_display_phone_number(cls, v):
@@ -117,4 +121,8 @@ class EmpresaModel(ChattyAssetModel):
             self.display_phone_number_value
             return True
         except ValueError:
-            return False
\ No newline at end of file
+            return False
+
+    @property
+    def good_quality_score_definition(self) -> str | None:
+        return self.messaging_settings.good_quality_score_definition
\ No newline at end of file
