@@ -14,13 +14,16 @@ class SmartFollowUpContextBuilder(ContextBuilder):
 
     @staticmethod
     def check_minimum_time_since_last_message(chat: Chat, follow_up_strategy: FollowUpStrategy,smart_follow_up_state: FlowStateAssignedToChat) -> bool:
-        expected_interval_minutes = follow_up_strategy.get_interval_for_followup(smart_follow_up_state.consecutive_count)
+        # consecutive_count is 0-indexed (0 = no follow-ups sent yet), but get_interval_for_followup expects 1-indexed
+        # So we add 1 to get the interval for the follow-up we're about to send
+        next_followup_number = smart_follow_up_state.consecutive_count + 1
+        expected_interval_minutes = follow_up_strategy.get_interval_for_followup(next_followup_number)
         last_message_timestamp = chat.last_message_timestamp
         if last_message_timestamp is None:
             raise HumanInterventionRequired("There's no last message in the chat, can't validate the minimum time since last message for the smart follow up")
         time_since_last_message = datetime.now(ZoneInfo('UTC')) - last_message_timestamp
         if time_since_last_message.total_seconds() < expected_interval_minutes * 60:
-            raise PostponeFollowUp(time_delta= timedelta(seconds=expected_interval_minutes * 60 - time_since_last_message.total_seconds()), message=f"Se pospuso el Smart Follow Up porque no ha pasado el tiempo mínimo esperado de {expected_interval_minutes/60} horas para el seguimiento #{smart_follow_up_state.consecutive_count}")
+            raise PostponeFollowUp(time_delta= timedelta(seconds=expected_interval_minutes * 60 - time_since_last_message.total_seconds()), message=f"Se pospuso el Smart Follow Up porque no ha pasado el tiempo mínimo esperado de {expected_interval_minutes/60} horas para el seguimiento #{next_followup_number}")
         return True
 
 
