@@ -6,7 +6,7 @@ read-only access to asset data using pre-configured AssetCollection subclasses.
 Perfect for services that only need to read asset data without CRUD operations.
 """
 from __future__ import annotations
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Any
 import logging
 
 # Import base components
@@ -24,7 +24,8 @@ from .collections import (
     SaleCollection,
     ContactPointCollection,
     AiAgentCollection,
-    FilterCriteriaCollection
+    FilterCriteriaCollection,
+    AiComponentCollection
 )
 
 # Import asset models for type hints
@@ -80,52 +81,57 @@ class AssetsCollections(metaclass=SingletonMeta):
         self.contact_points = ContactPointCollection(connection)
         self.ai_agents = AiAgentCollection(connection)
         self.filter_criterias = FilterCriteriaCollection(connection)
+        self.ai_components = AiComponentCollection(connection)
 
         logger.debug("AssetsCollections initialized successfully")
 
     # Convenience getter methods for easy access
 
-    def get_product_by_id(self, id: str) -> Product:
+    async def get_product_by_id(self, id: str) -> Product:
         """Get a product by ID."""
-        return self.products.get_by_id(id)
+        return await self.products.get_by_id(id)
 
-    def get_tag_by_id(self, id: str) -> Tag:
+    async def get_tag_by_id(self, id: str) -> Tag:
         """Get a tag by ID."""
-        return self.tags.get_by_id(id)
+        return await self.tags.get_by_id(id)
 
-    def get_user_by_id(self, id: str) -> User:
+    async def get_user_by_id(self, id: str) -> User:
         """Get a user by ID."""
-        return self.users.get_by_id(id)
+        return await self.users.get_by_id(id)
 
-    def get_chat_by_id(self, id: str) -> Chat:
+    async def get_chat_by_id(self, id: str) -> Chat:
         """Get a chat by ID."""
-        return self.chats.get_by_id(id)
+        return await self.chats.get_by_id(id)
 
-    def get_source_by_id(self, id: str) -> SourceBase:
+    async def get_source_by_id(self, id: str) -> SourceBase:
         """Get a source by ID."""
-        return self.sources.get_by_id(id)
+        return await self.sources.get_by_id(id)
 
-    def get_flow_by_id(self, id: str) -> FlowPreview:
+    async def get_flow_by_id(self, id: str) -> FlowPreview:
         """Get a flow by ID."""
-        return self.flows.get_by_id(id)
+        return await self.flows.get_by_id(id)
 
-    def get_sale_by_id(self, id: str) -> Sale:
+    async def get_sale_by_id(self, id: str) -> Sale:
         """Get a sale by ID."""
-        return self.sales.get_by_id(id)
+        return await self.sales.get_by_id(id)
 
-    def get_contact_point_by_id(self, id: str) -> ContactPoint:
+    async def get_contact_point_by_id(self, id: str) -> ContactPoint:
         """Get a contact point by ID."""
-        return self.contact_points.get_by_id(id)
+        return await self.contact_points.get_by_id(id)
 
-    def get_ai_agent_by_id(self, id: str) -> ChattyAIAgent:
+    async def get_ai_agent_by_id(self, id: str) -> ChattyAIAgent:
         """Get an AI agent by ID."""
-        return self.ai_agents.get_by_id(id)
+        return await self.ai_agents.get_by_id(id)
 
-    def get_filter_criteria_by_id(self, id: str) -> FilterCriteria:
+    async   def get_filter_criteria_by_id(self, id: str) -> FilterCriteria:
         """Get a filter criteria by ID."""
-        return self.filter_criterias.get_by_id(id)
+        return await self.filter_criterias.get_by_id(id)
 
-    def get_filter_criterias_by_ids(self, ids: list[str]) -> list[FilterCriteria]:
+    async def get_filter_criterias_by_ids(self, ids: list[str]) -> list[FilterCriteria]:
         """Get multiple filter criterias by their IDs in a single query."""
-        return self.filter_criterias.get_by_ids(ids)
+        return await self.filter_criterias.get_by_ids(ids=ids)
+
+    async def get_ai_components_by_ids(self, ids: list[str]) -> list[Any]:
+        """Get multiple AI components by their IDs in a single query."""
+        return await self.ai_components.get_by_ids(ids=ids)
 
