@@ -47,6 +47,8 @@ class AIAgentInChatService(AssetService[ChattyAIAgentInChat, ChattyAIAgentInChat
         """Update AI agent state"""
         ai_agent_in_chat.updated_at = datetime.now(ZoneInfo("UTC"))
         ai_agent_dict = ai_agent_in_chat.model_dump(by_alias=True, exclude_none=False)
+        # Remove _id field as it's immutable in MongoDB
+        ai_agent_dict.pop('_id', None)
         result = await self.collection.async_collection.update_one(
             {"chat_id": ai_agent_in_chat.chat_id},
             {"$set": ai_agent_dict}
@@ -65,7 +67,7 @@ class AIAgentInChatService(AssetService[ChattyAIAgentInChat, ChattyAIAgentInChat
 
     async def delete(self, chat_id: StrObjectId) -> None:
         """Delete AI agent state"""
-        result = await self.collection.async_collection.update_one({"chat_id": chat_id}, {"$set": {"deleted_at": datetime.now(ZoneInfo("UTC"))}})
-        if result.matched_count == 0:
+        result = await self.collection.async_collection.delete_one({"chat_id": chat_id})
+        if result.deleted_count == 0:
             raise ValueError(f"AI agent state for chat {chat_id} not found")
 
