@@ -1,6 +1,7 @@
 from typing import Optional, Dict, Any
 from datetime import datetime
 from ....models.analytics.events import *
+from ....models.analytics.events.chat_based_events.ai_agent_execution_event import AIAgentExecutionEvent
 from ....models.base_models.chatty_asset_model import ChattyAssetModel
 from ....models.company.assets.chat_assets import AssignedAssetToChat
 from ....models.company.empresa import EmpresaModel
@@ -611,4 +612,65 @@ class EventFactory:
             trace_id=trace_id
         )
         events.append(event)
-        return events
\ No newline at end of file
+        return events
+
+    @staticmethod
+    def ai_agent_execution_event(
+        event_type: EventType,
+        chat_id: StrObjectId,
+        company_id: StrObjectId,
+        frozen_company_name: str,
+        ai_agent_id: StrObjectId,
+        chain_of_thought_id: StrObjectId,
+        trigger: str,
+        source: str = "chatty.api",
+        decision_type: Optional[str] = None,
+        error_message: Optional[str] = None,
+        duration_ms: Optional[int] = None,
+        user_rating: Optional[int] = None,
+        metadata: Optional[Dict[str, Any]] = None,
+        trace_id: Optional[str] = None
+    ) -> AIAgentExecutionEvent:
+        """
+        Create an AI agent execution event using the modularized AIAgentEventFactory.
+
+        This method delegates to AIAgentEventFactory to maintain modularity while
+        keeping event creation centralized through EventsFactory.
+
+        Args:
+            event_type: The type of event (from EventType enum)
+            chat_id: ID of the chat where the event occurred
+            company_id: ID of the company
+            frozen_company_name: Company name snapshot for analytics
+            ai_agent_id: ID of the AI agent asset
+            chain_of_thought_id: ID of the chain of thought execution
+            trigger: What triggered the execution (USER_MESSAGE, FOLLOW_UP, etc.)
+            source: Event source (e.g., 'chatty.api', 'chatty.lambda')
+            decision_type: Type of decision if applicable
+            error_message: Error message if this is an error event
+            duration_ms: Duration of the operation in milliseconds
+            user_rating: User rating (1-5 stars) if applicable
+            metadata: Additional event-specific data
+            trace_id: Trace ID for tracking event flows
+
+        Returns:
+            AIAgentExecutionEvent ready to be queued to EventBridge
+        """
+        from .ai_agent_event_factory import AIAgentEventFactory
+
+        return AIAgentEventFactory.create_event(
+            event_type=event_type,
+            chat_id=chat_id,
+            company_id=company_id,
+            frozen_company_name=frozen_company_name,
+            ai_agent_id=ai_agent_id,
+            chain_of_thought_id=chain_of_thought_id,
+            trigger=trigger,
+            source=source,
+            decision_type=decision_type,
+            error_message=error_message,
+            duration_ms=duration_ms,
+            user_rating=user_rating,
+            metadata=metadata,
+            trace_id=trace_id
+        )
\ No newline at end of file
