@@ -1,6 +1,6 @@
 
 from letschatty.models import StrObjectId
-from letschatty.models.ai_microservices.lambda_events import DoubleCheckerForIncomingMessagesAnswerCallbackEvent, DoubleCheckerForIncomingMessagesAnswerEvent, FixBuggedAiAgentsCallsInChatsEvent, GetChainOfThoughtsByChatIdEvent, GetChatWithPromptForFollowUpEvent, GetChatWithPromptForIncomingMessageEvent, QualityTestEventData, QualityTestsForUpdatedAIComponentEvent, QualityTestsForUpdatedAIComponentEventData, ManualTriggerEvent, CancelExecutionEvent, AssignAIAgentToChatEvent, RemoveAIAgentFromChatEvent, UpdateAIAgentModeInChatEvent, EscalateAIAgentInChatEvent, UnescalateAIAgentInChatEvent
+from letschatty.models.ai_microservices.lambda_events import DoubleCheckerForIncomingMessagesAnswerCallbackEvent, DoubleCheckerForIncomingMessagesAnswerEvent, FixBuggedAiAgentsCallsInChatsEvent, GetChainOfThoughtsByChatIdEvent, GetChatWithPromptForFollowUpEvent, GetChatWithPromptForIncomingMessageEvent, QualityTestEventData, QualityTestsForUpdatedAIComponentEvent, QualityTestsForUpdatedAIComponentEventData, ManualTriggerEvent, CancelExecutionEvent, AssignAIAgentToChatEvent, RemoveAIAgentFromChatEvent, UpdateAIAgentModeInChatEvent, EscalateAIAgentInChatEvent, UnescalateAIAgentInChatEvent, SmartFollowUpDecisionOutputEvent
 from letschatty.models.ai_microservices.lambda_invokation_types import InvokationType
 from letschatty.models.ai_microservices import AllQualityTestEvent, AllQualityTestEventData, QualityTestEvent, QualityTestInteractionCallbackEvent, SmartTaggingCallbackEvent, QualityTestCallbackEvent, LambdaAiEvent, SmartTaggingEvent, SmartTaggingPromptEvent
 from letschatty.models.base_models.ai_agent_component import AiAgentComponent
@@ -55,6 +55,8 @@ class LambdaEventFactory:
                 return UnescalateAIAgentInChatEvent(**event_data)
             case InvokationType.GET_CHAIN_OF_THOUGHTS_BY_CHAT_ID:
                 return GetChainOfThoughtsByChatIdEvent(**event_data)
+            case InvokationType.SMART_FOLLOW_UP_DECISION_OUTPUT:
+                return SmartFollowUpDecisionOutputEvent(**event_data)
 
             case _:
                 raise ValueError(f"Invalid event type: {event_type}")
